==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/DrawingPreferences/UnitSettings/ts/UnitSettings_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>UnitSettings</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Drawing Unit:</source>
        <translatorcomment>--google--
&amp;Główna jednostka rysowania:
Główna jednostka rysowania:</translatorcomment>
        <translation type="unfinished">Rysowanie jednostkowe:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Paper Unit:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Jednostka papieru:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Measurement System (for line types and hatch patterns):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UnitSettings.js" line="+27"/>
        <source>Defaults for New Drawings</source>
        <translatorcomment>--ignored case--
--file: qcadguiqt_pl.ts--
Domyślne dla nowych rysunków</translatorcomment>
        <translation type="unfinished">Domyślne dla nowych rysunków</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+2"/>
        <source>Drawing Unit</source>
        <translatorcomment>--google--
&amp;Główna jednostka rysowania:
&amp;Główna jednostka rysowania
Główna jednostka rysowania:</translatorcomment>
        <translation type="unfinished">Rysowanie jednostkowe</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>General</source>
        <translatorcomment>--google--
Ogólne ustawienia aplikacji
[2000-206F] General Punctuation
General Punctuation</translatorcomment>
        <translation type="unfinished">Ogólny</translation>
    </message>
    <message>
        <location line="+71"/>
        <source>None</source>
        <translatorcomment>--exact match--
--file: qvfb_pl.ts--
Brak
Wyrażenia &quot;pragma&quot; nie są obsługiwane. Dlatego musi wystąpić wyrażenie zastępcze</translatorcomment>
        <translation type="unfinished">Brak</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Inch</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Dla formatu długości &quot;Inżynierski&quot; i &quot;Architektoniczny&quot;,jednostka musi byc ustawiona na cale.
Dla formatu długości &quot;Inżynierski&quot; i &quot;Architektoniczny&quot;,jednostka musi byc ustawiona na cale
Cal</translatorcomment>
        <translation type="unfinished">Cal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Foot</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Stopa</translatorcomment>
        <translation type="unfinished">Stopa</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Mile</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Mila</translatorcomment>
        <translation type="unfinished">Mila</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Millimeter</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Milimetr
Milimetry (mm)</translatorcomment>
        <translation type="unfinished">Milimetr</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Centimeter</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Centrymetr
Centymetry (cm)</translatorcomment>
        <translation type="unfinished">Centrymetr</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Meter</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Przełącz znak średnicy
ø (Średnica)</translatorcomment>
        <translation type="unfinished">Metr</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Kilometer</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Kilometr</translatorcomment>
        <translation type="unfinished">Kilometr</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Microinch</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Mikrocal</translatorcomment>
        <translation type="unfinished">Mikrocal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Mil</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
[0B80-0BFF] Tamil
Tamilski</translatorcomment>
        <translation type="unfinished">Mil</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Yard</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Jard</translatorcomment>
        <translation type="unfinished">Jard</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angstrom</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Angstrom</translatorcomment>
        <translation type="unfinished">Angstrom</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Nanometer</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Nanometr</translatorcomment>
        <translation type="unfinished">Nanometr</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Micron</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Mikron</translatorcomment>
        <translation type="unfinished">Mikron</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimeter</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Decymetr</translatorcomment>
        <translation type="unfinished">Decymetr</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decameter</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Dekametr</translatorcomment>
        <translation type="unfinished">Dekametr</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hectometer</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Hektometr</translatorcomment>
        <translation type="unfinished">Hektometr</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gigameter</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Gigametr</translatorcomment>
        <translation type="unfinished">Gigametr</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Astro</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Astro</translatorcomment>
        <translation type="unfinished">Astro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Lightyear</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Rok świetlny</translatorcomment>
        <translation type="unfinished">Rok świetlny</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Parsec</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Parsek</translatorcomment>
        <translation type="unfinished">Parsek</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Imperial</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Metric</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/DrawingPreferences/UnitSettings/ts/UnitSettings_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>UnitSettings</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Drawing Unit:</source>
        <translatorcomment>--google--
&amp;Główna jednostka rysowania:
Główna jednostka rysowania:</translatorcomment>
        <translation>Jednostka rysunku:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Paper Unit:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Jednostka papieru:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Measurement System (for line types and hatch patterns):</source>
        <translation>System miar (dla rodzajów linii i wzorów kreskowania):</translation>
    </message>
    <message>
        <location filename="../UnitSettings.js" line="+27"/>
        <source>Defaults for New Drawings</source>
        <translatorcomment>--ignored case--
--file: qcadguiqt_pl.ts--
Domyślne dla nowych rysunków</translatorcomment>
        <translation>Domyślne dla nowych rysunków</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+2"/>
        <source>Drawing Unit</source>
        <translatorcomment>--google--
&amp;Główna jednostka rysowania:
&amp;Główna jednostka rysowania
Główna jednostka rysowania:</translatorcomment>
        <translation>Jednostki</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>General</source>
        <translatorcomment>--google--
Ogólne ustawienia aplikacji
[2000-206F] General Punctuation
General Punctuation</translatorcomment>
        <translation>Ogólne</translation>
    </message>
    <message>
        <location line="+71"/>
        <source>None</source>
        <translatorcomment>--exact match--
--file: qvfb_pl.ts--
Brak
Wyrażenia &quot;pragma&quot; nie są obsługiwane. Dlatego musi wystąpić wyrażenie zastępcze</translatorcomment>
        <translation>Brak</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Inch</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Dla formatu długości &quot;Inżynierski&quot; i &quot;Architektoniczny&quot;,jednostka musi byc ustawiona na cale.
Dla formatu długości &quot;Inżynierski&quot; i &quot;Architektoniczny&quot;,jednostka musi byc ustawiona na cale
Cal</translatorcomment>
        <translation>Cal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Foot</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Stopa</translatorcomment>
        <translation>Stopa</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Mile</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Mila</translatorcomment>
        <translation>Mila</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Millimeter</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Milimetr
Milimetry (mm)</translatorcomment>
        <translation>Milimetr</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Centimeter</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Centrymetr
Centymetry (cm)</translatorcomment>
        <translation>Centymetr</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Meter</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Przełącz znak średnicy
ø (Średnica)</translatorcomment>
        <translation>Metr</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Kilometer</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Kilometr</translatorcomment>
        <translation>Kilometr</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Microinch</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Mikrocal</translatorcomment>
        <translation>Mikrocal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Mil</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
[0B80-0BFF] Tamil
Tamilski</translatorcomment>
        <translation>Mila</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Yard</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Jard</translatorcomment>
        <translation>Jard</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angstrom</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Angstrom</translatorcomment>
        <translation>Angstrem</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Nanometer</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Nanometr</translatorcomment>
        <translation>Nanometr</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Micron</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Mikron</translatorcomment>
        <translation>Mikron</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimeter</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Decymetr</translatorcomment>
        <translation>Decymetr</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decameter</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Dekametr</translatorcomment>
        <translation>Dekametr</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hectometer</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Hektometr</translatorcomment>
        <translation>Hektometr</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gigameter</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Gigametr</translatorcomment>
        <translation>Gigametr</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Astro</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Astro</translatorcomment>
        <translation>Jednostka astronomiczna</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Lightyear</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Rok świetlny</translatorcomment>
        <translation>Rok świetlny</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Parsec</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Parsek</translatorcomment>
        <translation>Parsek</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Imperial</source>
        <translation>Imperialny</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Metric</source>
        <translation>Metryczny</translation>
    </message>
</context>
</TS>
